@@ -118,7 +118,7 @@ func TestProcessBGPUpdate_0_select_onlypath_ipv4(t *testing.T) {
 
 	// check destination
 	expectedPrefix := "10.10.10.0/24"
-	assert.Equal(t, expectedPrefix, path.getPrefix())
+	assert.Equal(t, expectedPrefix, path.GetPrefix())
 	// check nexthop
 	expectedNexthop := "192.168.50.1"
 	assert.Equal(t, expectedNexthop, path.GetNexthop().String())
@@ -169,7 +169,7 @@ func TestProcessBGPUpdate_0_select_onlypath_ipv6(t *testing.T) {
 
 	// check destination
 	expectedPrefix := "2001:123:123:1::/64"
-	assert.Equal(t, expectedPrefix, path.getPrefix())
+	assert.Equal(t, expectedPrefix, path.GetPrefix())
 	// check nexthop
 	expectedNexthop := "2001::192:168:50:1"
 	assert.Equal(t, expectedNexthop, path.GetNexthop().String())
@@ -250,7 +250,7 @@ func TestProcessBGPUpdate_1_select_high_localpref_ipv4(t *testing.T) {
 
 	// check destination
 	expectedPrefix := "10.10.10.0/24"
-	assert.Equal(t, expectedPrefix, path.getPrefix())
+	assert.Equal(t, expectedPrefix, path.GetPrefix())
 	// check nexthop
 	expectedNexthop := "192.168.50.1"
 	assert.Equal(t, expectedNexthop, path.GetNexthop().String())
@@ -331,7 +331,7 @@ func TestProcessBGPUpdate_1_select_high_localpref_ipv6(t *testing.T) {
 
 	// check destination
 	expectedPrefix := "2001:123:123:1::/64"
-	assert.Equal(t, expectedPrefix, path.getPrefix())
+	assert.Equal(t, expectedPrefix, path.GetPrefix())
 	// check nexthop
 	expectedNexthop := "2001::192:168:100:1"
 	assert.Equal(t, expectedNexthop, path.GetNexthop().String())
@@ -414,7 +414,7 @@ func TestProcessBGPUpdate_2_select_local_origin_ipv4(t *testing.T) {
 
 	// check destination
 	expectedPrefix := "10.10.10.0/24"
-	assert.Equal(t, expectedPrefix, path.getPrefix())
+	assert.Equal(t, expectedPrefix, path.GetPrefix())
 	// check nexthop
 	expectedNexthop := "0.0.0.0"
 	assert.Equal(t, expectedNexthop, path.GetNexthop().String())
@@ -498,7 +498,7 @@ func TestProcessBGPUpdate_2_select_local_origin_ipv6(t *testing.T) {
 
 	// check destination
 	expectedPrefix := "2001:123:123:1::/64"
-	assert.Equal(t, expectedPrefix, path.getPrefix())
+	assert.Equal(t, expectedPrefix, path.GetPrefix())
 	// check nexthop
 	expectedNexthop := "::"
 	assert.Equal(t, expectedNexthop, path.GetNexthop().String())
@@ -554,7 +554,7 @@ func TestProcessBGPUpdate_3_select_aspath_ipv4(t *testing.T) {
 
 	// check destination
 	expectedPrefix := "20.20.20.0/24"
-	assert.Equal(t, expectedPrefix, path.getPrefix())
+	assert.Equal(t, expectedPrefix, path.GetPrefix())
 	// check nexthop
 	expectedNexthop := "192.168.100.1"
 	assert.Equal(t, expectedNexthop, path.GetNexthop().String())
@@ -610,7 +610,7 @@ func TestProcessBGPUpdate_3_select_aspath_ipv6(t *testing.T) {
 
 	// check destination
 	expectedPrefix := "2002:223:123:1::/64"
-	assert.Equal(t, expectedPrefix, path.getPrefix())
+	assert.Equal(t, expectedPrefix, path.GetPrefix())
 	// check nexthop
 	expectedNexthop := "2001::192:168:100:1"
 	assert.Equal(t, expectedNexthop, path.GetNexthop().String())
@@ -691,7 +691,7 @@ func TestProcessBGPUpdate_4_select_low_origin_ipv4(t *testing.T) {
 
 	// check destination
 	expectedPrefix := "10.10.10.0/24"
-	assert.Equal(t, expectedPrefix, path.getPrefix())
+	assert.Equal(t, expectedPrefix, path.GetPrefix())
 	// check nexthop
 	expectedNexthop := "192.168.100.1"
 	assert.Equal(t, expectedNexthop, path.GetNexthop().String())
@@ -772,7 +772,7 @@ func TestProcessBGPUpdate_4_select_low_origin_ipv6(t *testing.T) {
 
 	// check destination
 	expectedPrefix := "2001:123:123:1::/64"
-	assert.Equal(t, expectedPrefix, path.getPrefix())
+	assert.Equal(t, expectedPrefix, path.GetPrefix())
 	// check nexthop
 	expectedNexthop := "2001::192:168:100:1"
 	assert.Equal(t, expectedNexthop, path.GetNexthop().String())
@@ -853,7 +853,7 @@ func TestProcessBGPUpdate_5_select_low_med_ipv4(t *testing.T) {
 
 	// check destination
 	expectedPrefix := "10.10.10.0/24"
-	assert.Equal(t, expectedPrefix, path.getPrefix())
+	assert.Equal(t, expectedPrefix, path.GetPrefix())
 	// check nexthop
 	expectedNexthop := "192.168.100.1"
 	assert.Equal(t, expectedNexthop, path.GetNexthop().String())
@@ -934,7 +934,7 @@ func TestProcessBGPUpdate_5_select_low_med_ipv6(t *testing.T) {
 
 	// check destination
 	expectedPrefix := "2001:123:123:1::/64"
-	assert.Equal(t, expectedPrefix, path.getPrefix())
+	assert.Equal(t, expectedPrefix, path.GetPrefix())
 	// check nexthop
 	expectedNexthop := "2001::192:168:100:1"
 	assert.Equal(t, expectedNexthop, path.GetNexthop().String())
@@ -1015,7 +1015,7 @@ func TestProcessBGPUpdate_6_select_ebgp_path_ipv4(t *testing.T) {
 
 	// check destination
 	expectedPrefix := "10.10.10.0/24"
-	assert.Equal(t, expectedPrefix, path.getPrefix())
+	assert.Equal(t, expectedPrefix, path.GetPrefix())
 	// check nexthop
 	expectedNexthop := "192.168.100.1"
 	assert.Equal(t, expectedNexthop, path.GetNexthop().String())
@@ -1096,7 +1096,7 @@ func TestProcessBGPUpdate_6_select_ebgp_path_ipv6(t *testing.T) {
 
 	// check destination
 	expectedPrefix := "2001:123:123:1::/64"
-	assert.Equal(t, expectedPrefix, path.getPrefix())
+	assert.Equal(t, expectedPrefix, path.GetPrefix())
 	// check nexthop
 	expectedNexthop := "2001::192:168:100:1"
 	assert.Equal(t, expectedNexthop, path.GetNexthop().String())
@@ -1180,7 +1180,7 @@ func TestProcessBGPUpdate_7_select_low_routerid_path_ipv4(t *testing.T) {
 
 	// check destination
 	expectedPrefix := "10.10.10.0/24"
-	assert.Equal(t, expectedPrefix, path.getPrefix())
+	assert.Equal(t, expectedPrefix, path.GetPrefix())
 	// check nexthop
 	expectedNexthop := "192.168.100.1"
 	assert.Equal(t, expectedNexthop, path.GetNexthop().String())
@@ -1261,7 +1261,7 @@ func TestProcessBGPUpdate_7_select_low_routerid_path_ipv6(t *testing.T) {
 
 	// check destination
 	expectedPrefix := "2001:123:123:1::/64"
-	assert.Equal(t, expectedPrefix, path.getPrefix())
+	assert.Equal(t, expectedPrefix, path.GetPrefix())
 	// check nexthop
 	expectedNexthop := "2001::192:168:100:1"
 	assert.Equal(t, expectedNexthop, path.GetNexthop().String())
@@ -1344,7 +1344,7 @@ func TestProcessBGPUpdate_8_withdraw_path_ipv4(t *testing.T) {
 	checkPattr(bgpMessage2, path)
 	// check destination
 	expectedPrefix := "10.10.10.0/24"
-	assert.Equal(t, expectedPrefix, path.getPrefix())
+	assert.Equal(t, expectedPrefix, path.GetPrefix())
 	// check nexthop
 	expectedNexthop := "192.168.100.1"
 	assert.Equal(t, expectedNexthop, path.GetNexthop().String())
@@ -1365,7 +1365,7 @@ func TestProcessBGPUpdate_8_withdraw_path_ipv4(t *testing.T) {
 	checkPattr(bgpMessage1, path)
 	// check destination
 	expectedPrefix = "10.10.10.0/24"
-	assert.Equal(t, expectedPrefix, path.getPrefix())
+	assert.Equal(t, expectedPrefix, path.GetPrefix())
 	// check nexthop
 	expectedNexthop = "192.168.50.1"
 	assert.Equal(t, expectedNexthop, path.GetNexthop().String())
@@ -1472,7 +1472,7 @@ func TestProcessBGPUpdate_8_mpunreach_path_ipv6(t *testing.T) {
 
 	// check destination
 	expectedPrefix := "2001:123:123:1::/64"
-	assert.Equal(t, expectedPrefix, path.getPrefix())
+	assert.Equal(t, expectedPrefix, path.GetPrefix())
 	// check nexthop
 	expectedNexthop := "2001::192:168:100:1"
 	assert.Equal(t, expectedNexthop, path.GetNexthop().String())
@@ -1492,7 +1492,7 @@ func TestProcessBGPUpdate_8_mpunreach_path_ipv6(t *testing.T) {
 	checkPattr(bgpMessage1, path)
 	// check destination
 	expectedPrefix = "2001:123:123:1::/64"
-	assert.Equal(t, expectedPrefix, path.getPrefix())
+	assert.Equal(t, expectedPrefix, path.GetPrefix())
 	// check nexthop
 	expectedNexthop = "2001::192:168:50:1"
 	assert.Equal(t, expectedNexthop, path.GetNexthop().String())
@@ -1567,7 +1567,7 @@ func TestProcessBGPUpdate_bestpath_lost_ipv4(t *testing.T) {
 	checkPattr(bgpMessage1, path)
 	// check destination
 	expectedPrefix := "10.10.10.0/24"
-	assert.Equal(t, expectedPrefix, path.getPrefix())
+	assert.Equal(t, expectedPrefix, path.GetPrefix())
 }
 
 func TestProcessBGPUpdate_bestpath_lost_ipv6(t *testing.T) {
@@ -1637,7 +1637,7 @@ func TestProcessBGPUpdate_bestpath_lost_ipv6(t *testing.T) {
 
 	// check destination
 	expectedPrefix := "2001:123:123:1::/64"
-	assert.Equal(t, expectedPrefix, path.getPrefix())
+	assert.Equal(t, expectedPrefix, path.GetPrefix())
 }
 
 // test: implicit withdrawal case
@@ -1715,7 +1715,7 @@ func TestProcessBGPUpdate_implicit_withdrwal_ipv4(t *testing.T) {
 	checkPattr(bgpMessage2, path)
 	// check destination
 	expectedPrefix := "10.10.10.0/24"
-	assert.Equal(t, expectedPrefix, path.getPrefix())
+	assert.Equal(t, expectedPrefix, path.GetPrefix())
 	// check nexthop
 	expectedNexthop := "192.168.50.1"
 	assert.Equal(t, expectedNexthop, path.GetNexthop().String())
@@ -1821,7 +1821,7 @@ func TestProcessBGPUpdate_implicit_withdrwal_ipv6(t *testing.T) {
 
 	// check destination
 	expectedPrefix := "2001:123:123:1::/64"
-	assert.Equal(t, expectedPrefix, path.getPrefix())
+	assert.Equal(t, expectedPrefix, path.GetPrefix())
 	// check nexthop
 	expectedNexthop := "2001::192:168:50:1"
 	assert.Equal(t, expectedNexthop, path.GetNexthop().String())
@@ -1876,7 +1876,7 @@ func TestProcessBGPUpdate_multiple_nlri_ipv4(t *testing.T) {
 		assert.Equal(t, p.GetRouteFamily(), rf)
 		checkPattr(m, p)
 		// check destination
-		assert.Equal(t, prefix, p.getPrefix())
+		assert.Equal(t, prefix, p.GetPrefix())
 		// check nexthop
 		assert.Equal(t, nexthop, p.GetNexthop().String())
 	}
@@ -2014,7 +2014,7 @@ func TestProcessBGPUpdate_multiple_nlri_ipv6(t *testing.T) {
 		assert.Equal(t, p.GetRouteFamily(), rf)
 		checkPattr(m, p)
 		// check destination
-		assert.Equal(t, prefix, p.getPrefix())
+		assert.Equal(t, prefix, p.GetPrefix())
 		// check nexthop
 		assert.Equal(t, nexthop, p.GetNexthop().String())
 	}
